// java wrapper for vtkInteractorStyle3D object
//

package vtk;
import vtk.*;

public class vtkInteractorStyle3D extends vtkInteractorStyle
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDollyPhysicalSpeed_2(double id0);
  public void SetDollyPhysicalSpeed(double id0)
    { SetDollyPhysicalSpeed_2(id0); }

  private native double GetDollyPhysicalSpeed_3();
  public double GetDollyPhysicalSpeed()
    { return GetDollyPhysicalSpeed_3(); }

  private native void SetScale_4(vtkCamera id0,double id1);
  public void SetScale(vtkCamera id0,double id1)
    { SetScale_4(id0,id1); }

  private native long GetInteractionPicker_5();
  public vtkPropPicker GetInteractionPicker() {
    long temp = GetInteractionPicker_5();

    if (temp == 0) return null;
    return (vtkPropPicker)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkInteractorStyle3D() { super(); }

  public vtkInteractorStyle3D(long id) { super(id); }
  public native long   VTKInit();

}
